% SegyTimeAdjust permit to correct small errors in the scaling on SEGY files
% dues to errors in the origin of the trace during digitizing process.
% Marcell Farran (mfarran@icm.csic.es) ICM(CSIC), Barcelona Spain
% This program needs SegyMAT library in your Matlab path
% (SegyMAT(C) 2001-2008 T. Mejer Hansen http://segymat.sourceforge.net/)
% Normal  errors are about some miliseconds (less than 10).
% Give Positive values when recorded time (time lines) in the original record
% are over the time lines in the SegY viewer display.

% _________correction Value______________________

clear all;
defValue={'0'};
prompt={'ms, positive values lowers the scanned time marks'};title='ERROR in MiliSeconds';lines=[1,40]; 
answer=inputdlg(prompt,title,lines,defValue);
assignin('base','Time_error',answer{1});
time_adjust=str2num(answer{1}); % in milisec positive if original time-marks must be deeper 
if time_adjust==0, msgbox('No correction for 0 ms ','SegyTimeAdjust','help'),return;
end;

%_________Files input output________________________

[SGY_infile,pathname]=uigetfile( ...
{'*.seg;*.sgy','Format SEG-Y (*.seg,*.sgy)';
    '*.*',  'all (*.*)'}, ...
    'Input: SEG-Y file with timimg error');
infile=[pathname SGY_infile];
disp(infile);
[SGY_outfile,pathname]=uiputfile( ...
{'*.seg;*.sgy','Format SEG-Y (*.seg,*.sgy)';
    '*.*',  'all (*.*)'}, ...
    'Output: SEG-Y corrected file');
outfile=[pathname SGY_outfile];
disp(outfile);
[Data,SegyTraceHeaders,SegyHeader]=ReadSegy(infile);

%_________________Calculus__________________________

[rows,cols]= size(Data);
NewData=zeros(rows,cols);
SamplToMove= int16((time_adjust *1000)/ SegyHeader.dt);
RowStart=abs(SamplToMove)+1;
if SamplToMove>0 
    RowEnd=rows-SamplToMove;
    NewData(RowStart:rows,:)=Data(1:RowEnd,:);
else                          %negative values)
    RowEnd=rows+SamplToMove;
    NewData(1:RowEnd,:)=Data(RowStart:rows,:);   
end;

% ___________write data________________________________

WriteSegyStructure(outfile,SegyHeader,SegyTraceHeaders,NewData,'dsf',3);
disp('NEW SEGY FILE CREATED');
clear all; close all; beep;
%____________________END __________________________

